@@ -34,22 +34,33 @@ OC.L10N.register(
     "Calls are disabled in this conversation." : "Samtal är inaktiverade i den här konversationen.",
     "Go to file" : "Gå till fil",
     "Share link" : "Dela länk",
+    "Copy link" : "Kopiera länk",
+    "Enable for" : "Aktivera för",
+    "All participants" : "Alla deltagare",
+    "Moderators only" : "Endast moderatorer",
+    "Start time (optional)" : "Starttid (valfritt)",
     "Change password" : "Byt lösenord",
     "Set password" : "Sätt lösenord",
+    "Error occurred while renaming the room" : "Fel uppstod vid namnändring av rum",
     "Name" : "Namn",
     "Conversation name" : "Konversationens namn",
     "Rename" : "Byt namn",
-    "Copy link" : "Kopiera länk",
-    "Conversation with {name}" : "Konversation med {name}",
-    "Error occurred while setting password" : "Fel inträffade när lösenord sattes",
     "Link copied!" : "Länk kopierad!",
+    "Conversation with {name}" : "Konversation med {name}",
+    "Error occurred while making the room public" : "Fel uppstod när rummet skulle göras offentligt",
+    "Error occurred while making the room private" : "Fel uppstod när rummet skulle göras privat",
+    "Error occurred while setting password" : "Fel inträffade när lösenord sattes",
+    "Error occurred while enabling for all participants" : "Fel uppstod vid aktivering för alla deltagare",
+    "Error occurred while enabling only for moderators" : "Fel uppstod vid aktivering för endast moderatorer",
+    "Invalid start time format" : "Ogiltigt format för starttid",
+    "Error occurred while setting the lobby start time" : "Fel uppstod vid inställning av starttid för lobby",
     "You" : "Du",
+    "Guest" : "Gäst",
     "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
     "New message …" : "Nytt meddelande",
     "Send" : "Skicka",
     "You can not send messages, because the conversation is locked." : "Du kan inte skicka meddelanden, eftersom konversationen är låst.",
     "The conversation is locked." : "Konversationen är låst.",
-    "Guest" : "Gäst",
     "[Unknown user name]" : "[Okänt användarnam]",
     "Today" : "Idag",
     "Yesterday" : "Igår",
@@ -61,6 +72,8 @@ OC.L10N.register(
     "Edit" : "Ändra",
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
     "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
+    "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
     "No other people in this call" : "Inga andra personer i detta samtal",
     "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
     "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
@@ -108,6 +121,7 @@ OC.L10N.register(
     "Add to favorites" : "Lägg till som favorit",
     "Chat notifications" : "Chatt-notifieringar",
     "All messages" : "Alla meddelanden",
+    "@-mentions only" : "@-mentions only",
     "Off" : "Av",
     "Leave conversation" : "Lämna konversationen",
     "Delete conversation" : "Radera konversationen",
@@ -116,6 +130,7 @@ OC.L10N.register(
     "{participantName}'s screen" : "{participantName}'s skärm",
     "Guest's screen" : "Gästskärm",
     "Close" : "Stäng",
+    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
     "Show screen" : "Visa skärm",
     "Enable video" : "Aktivera video",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
@@ -134,7 +149,7 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i ett samtal med {user1}, {user2}, {user3}, {user4} och {user5}",
     "_%n other_::_%n others_" : ["%n annan","%n andra"],
     "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
-    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
+    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du blev inbjuden till en <strong>konversation</strong> eller hade ett <strong>samtal</strong>",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Välkommen till Nextcloud Talk!\nI denna konversation kommer du att bli informerad om nya funktioner som finns i Nextcloud Talk.",
     "New in Talk 6" : "Nytt i Talk 6",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
@@ -143,8 +158,12 @@ OC.L10N.register(
     "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
     "- With projects you can create quick links between conversations, files and other items" : "- Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
+    "New in Talk 7" : "Nytt i Talk 7",
+    "- You can now mention guests in the chat" : "- Du kan nu nämna gäster i chatten",
+    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
     "Talk updates ✅" : "Talk uppdateringar ✅",
     "{actor} created the conversation" : "{actor} skapade konversationen",
     "You created the conversation" : "Du skapade konversationen",
@@ -160,6 +179,11 @@ OC.L10N.register(
     "You unlocked the conversation" : "Du låste upp konversationen",
     "{actor} locked the conversation" : "{actor} låste konversationen",
     "You locked the conversation" : "Du låste konversationen",
+    "The conversation is now open to everyone" : "Konversationen är nu öppen för alla",
+    "{actor} opened the conversation to everyone" : "{actor} öppnade konversationen för alla",
+    "You opened the conversation to everyone" : "Du öppnade konversationen för alla",
+    "{actor} restricted the conversation to moderators" : "{actor} begränsade konversationen till moderatorer",
+    "You restricted the conversation to moderators" : "Du begränsade konversationen till moderatorer",
     "{actor} allowed guests" : "{actor} tillåter gäster",
     "You allowed guests" : "Du tillåter gäster",
     "{actor} disallowed guests" : "{actor} tillåter inte gäster",
@@ -187,6 +211,7 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
     "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
     "%s (guest)" : "%s (gäst)",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} (Varade {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
@@ -204,10 +229,17 @@ OC.L10N.register(
     "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
     "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
     "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
+    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gäst) skickade ett meddelande i konversationen {call}",
     "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
+    "{user} replied to your private message" : "{user} svarade på ditt privata meddelande",
+    "{user} replied to your message in conversation {call}" : "{user} svarade på ditt meddelande i konversationen {call}",
+    "A deleted user replied to your message in conversation {call}" : "En raderad användare svarade på ditt meddelande i konversationen {call}",
+    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gäst) svarade på ditt meddelande i konversationen {call}",
+    "A guest replied to your message in conversation {call}" : "En gäst svarade på ditt meddelande i konversationen {call}",
     "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
     "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
     "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
+    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gäst) nämnde dig i konversationen {call}",
     "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
     "View chat" : "Visa chatt",
     "{user} invited you to a private conversation" : "{user} bjöd in dig till en privat konversation",
@@ -257,6 +289,9 @@ OC.L10N.register(
     "Response to" : "Svar till",
     "Enabled for" : "Aktiverad för",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandon är en ny beta-funktion i Nextcloud Talk. Det låter dig köra skript på din Nextcloud-server. Du kan definiera dem med vårt kommandoradsgränssnitt. Ett exempel på ett kalkylatorskript finns i vår <a {attributes}>dokumentation ↗</a>.",
+    "General settings" : "Allmänna inställningar",
+    "Start calls" : "Starta samtal",
+    "Users and moderators" : "Användare och moderatorer",
     "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
     "Select conversation" : "Välj konversation",
     "Signaling servers" : "Signalservrar",
@@ -285,40 +320,16 @@ OC.L10N.register(
     "Delete server" : "Ta bort server",
     "Add new server" : "Lägg till ny server",
     "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du raderade alla STUN-servrar. Eftersom det nästan alltid behövs har en standard STUN-server lagts till.",
-    "TURN candidate generation failed, please check the settings." : "TURN-generering misslyckades, kontrollera inställningarna.",
-    "The TURN server settings are valid." : "TURN-serverns inställningar är giltiga.",
-    "Checking TURN server {server}" : "Kontrollerar TURN-servern {server}",
     "TURN server shared secret" : "TURN server delade hemlighet",
     "Test server" : "Testa server",
     "New public conversation" : "Ny publik konversation",
     "New group conversation" : "Ny gruppkonversation",
-    "Password request by %s" : "Lösenordet efterfrågas av %s",
-    "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
-    ", " : ",",
-    "%s mentioned you in a private conversation" : "%s nämnde dig i en privat konversation",
-    "%s mentioned you in a group conversation: %s" : "%s nämnde dig i en gruppkonversation: %s",
-    "{user} mentioned you in a group conversation: {call}" : "{user} nämnde dig i en gruppkonversation: {call}",
-    "%s mentioned you in a group conversation" : "%s nämnde dig i en gruppkonversation",
-    "{user} mentioned you in a group conversation" : "{user} nämnde dig i en gruppkonversation",
-    "You were mentioned in a group conversation by a deleted user: %s" : "Du nämndes i en gruppkonversation av en raderad användare: %s",
-    "You were mentioned in a group conversation by a deleted user: {call}" : "Du nämndes i en gruppkonversation av en raderad användare: {call}",
-    "You were mentioned in a group conversation by a deleted user" : "Du nämndes i en gruppkonversation av en raderad användare",
-    "A guest mentioned you in a group conversation: %s" : "En gäst nämnde dig i en gruppkonversation: %s",
-    "A guest mentioned you in a group conversation: {call}" : "En gäst nämnde dig i en gruppkonversation: {call}",
-    "A guest mentioned you in a group conversation" : "En gäst nämnde dig i en gruppkonversation",
-    "%s invited you to a private conversation" : "%s bjöd in dig till en privat konversation",
-    "%s invited you to a group conversation: %s" : "%s bjöd in dig till en gruppkonversation: %s",
-    "%s invited you to a group conversation" : "%s bjöd in dig till en gruppkonversation",
-    "{user} invited you to a group conversation" : "{user} bjöd in dig till en gruppkonversation",
-    "A group call has started" : "Ett gruppsamtal har startats",
-    "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning",
-    "Unnamed conversation" : "Namnlös konversation",
-    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
-    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
-    "Signaling server" : "Signalserver",
     "Always notify" : "Meddela alltid",
     "Notify on @-mention" : "Meddela på @-mention",
     "Never notify" : "Meddela aldrig",
+    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
+    "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
+    ", " : ",",
     "Join now" : "Anslut nu",
     "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
     "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
@@ -326,8 +337,17 @@ OC.L10N.register(
     "{user} mentioned you in a conversation" : "{user} nämnde dig i en konversation",
     "A deleted user mentioned you in a conversation" : "En raderad användare nämnde dig i en konversation",
     "A guest mentioned you in a conversation" : "En gäst nämnde dig i en konversation",
+    "%s invited you to a private conversation" : "%s bjöd in dig till en privat konversation",
+    "%s invited you to a group conversation: %s" : "%s bjöd in dig till en gruppkonversation: %s",
+    "%s invited you to a group conversation" : "%s bjöd in dig till en gruppkonversation",
+    "{user} invited you to a group conversation" : "{user} bjöd in dig till en gruppkonversation",
+    "A group call has started" : "Ett gruppsamtal har startats",
     "{email} requested the password to access {file}" : "{email} begärde lösenordet för åtkomst till {file}",
     "Someone requested the password to access {file}" : "Någon begärde lösenordet för att komma åt {file}",
+    "Unnamed conversation" : "Namnlös konversation",
+    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
+    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
+    "Signaling server" : "Signalserver",
     "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
     "* One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "* En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
     "* You can now notify all participants by posting \"@all\" into the chat" : "* Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
